LinMaze module
==============
The module used for making training protocolls in a 2D virtual linear maze. The user can define Levels that contain Frames (patterns the animal can see), Events (things that can happen to the animal in the simulation) and Rules (conditions for Events).

Main module
-----------
.. toctree::
   :maxdepth: 2

   linmaze_main

Level
-----
.. toctree::
   :maxdepth: 2

   level

Frame
-----
.. toctree::
   :maxdepth: 2

   frame


Event
-----
.. toctree::
   :maxdepth: 2

   event

Rule
----
.. toctree::
   :maxdepth: 2

   rule

Zone
----
.. toctree::
   :maxdepth: 2

   zone

Output
------
.. toctree::
   :maxdepth: 2

   linmaze_out